Recibo do Sacado Nosso Número Vencimento Agência/Código do Beneficiário Valor Documento 00000000000000401-4 31/05/2011 0531-2 / 05705853-9 5,00 Sale 00123 - Description Autenticação Mecânica / Ficha de Compensação Código de baixa Pagador / Avalista Pagador Client Mainstreet 138, Cidade Araci 12345-678 - Los Angeles - Californa (=) Valor cobrado (+) Outros acréscimos (+) Mora/Multa (-) Outras deduções (-) Descontos/Abatimentos Instruções Primeia linha da instrução Uso do banco Carteira Espécie Quantidade Valor (=) Valor documento 06 R$ 5,00 Data do documento N. do documento Espécie doc Aceite Data processamento Nosso número 30/05/2011 00401 DM N 30/05/2011 00000000000000401-4 Beneficiário Agência/Código Beneficiário Moda Stoq 0531-2 / 05705853-9 Local de pagamento Vencimento Pagável em qualquer banco até o vencimento 31/05/2011 001-9 00190.00009 00000.000000 00000.401067 8 49840000000500 Recibo do Sacado Nosso Número Vencimento Agência/Código do Beneficiário Valor Documento 00000000000000400-6 30/05/2011 0531-2 / 05705853-9 5,00 Sale 00123 - Description Autenticação Mecânica / Ficha de Compensação Código de baixa Pagador / Avalista Pagador Client Mainstreet 138, Cidade Araci 12345-678 - Los Angeles - Californa (=) Valor cobrado (+) Outros acréscimos (+) Mora/Multa (-) Outras deduções (-) Descontos/Abatimentos Instruções Primeia linha da instrução Uso do banco Carteira Espécie Quantidade Valor (=) Valor documento 06 R$ 5,00 Data do documento N. do documento Espécie doc Aceite Data processamento Nosso número 30/05/2011 00400 DM N 30/05/2011 00000000000000400-6 Beneficiário Agência/Código Beneficiário Moda Stoq 0531-2 / 05705853-9 Local de pagamento Vencimento Pagável em qualquer banco até o vencimento 30/05/2011 001-9 00190.00009 00000.000000 00000.400069 6 49830000000500